@@ -1,9 +1,7 @@
+"""This is the database module, which contains the database class, also a cache class."""
+
 from authx.database.base import BaseDBBackend
 from authx.database.encodedb import EncodeDBBackend
 from authx.database.mongodb import MongoDBBackend
 
-"""
-    This is the database module, which contains the database class, also a cache class.
-"""
-
 __all__ = ["BaseDBBackend", "MongoDBBackend", "EncodeDBBackend"]
